aboutsummaryrefslogtreecommitdiff
path: root/engines
diff options
context:
space:
mode:
authorSven Hesse2010-10-05 21:22:30 +0000
committerSven Hesse2010-10-05 21:22:30 +0000
commit7ffd94004ec7fdf04e83c90a35f7d7910b12a6ce (patch)
treefc3fdc316daeec6d170f3d3c2a3a21ea6efe58ea /engines
parent2a99d3d4b14e34190cd730bb834c60131324ff0f (diff)
downloadscummvm-rg350-7ffd94004ec7fdf04e83c90a35f7d7910b12a6ce.tar.gz
scummvm-rg350-7ffd94004ec7fdf04e83c90a35f7d7910b12a6ce.tar.bz2
scummvm-rg350-7ffd94004ec7fdf04e83c90a35f7d7910b12a6ce.zip
GOB: Try to also open VMD files in Gob3 Win
Because the scripts reference it as IMD, while there are actually only VMDs files in the data files of the Windows version svn-id: r53037
Diffstat (limited to 'engines')
-rw-r--r--engines/gob/mult_v2.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/gob/mult_v2.cpp b/engines/gob/mult_v2.cpp
index 4da53097fc..6fc292950f 100644
--- a/engines/gob/mult_v2.cpp
+++ b/engines/gob/mult_v2.cpp
@@ -272,9 +272,9 @@ void Mult_v2::loadImds(Common::SeekableReadStream &data) {
memcpy(_multData->imdFiles,
_vm->_game->_script->getData() + _vm->_game->_script->pos(), size * 14);
- // WORKAROUND: The Windows version of Lost in Time has VMD not IMD files,
- // but they are still referenced as IMD.
- if ((_vm->getGameType() == kGameTypeLostInTime) &&
+ // WORKAROUND: The Windows versions of Lost in Time and Gob3 have VMD not
+ // IMD files, but they are still referenced as IMD.
+ if (((_vm->getGameType() == kGameTypeLostInTime) || (_vm->getGameType() == kGameTypeGob3)) &&
(_vm->getPlatform() == Common::kPlatformWindows)) {
for (int i = 0; i < size; i++) {